@@ -671,7 +671,7 @@ $angle = 0;
             }
         );
         $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
-        $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
+        $rot->{'y'} = $F->{'Y_CLIP'} + abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
 
         $F->blit_write($rot);
 
@@ -692,7 +692,7 @@ $angle = 0;
             }
         );
         $rot->{'x'} = abs(($XX - $rot->{'width'})  / 2);
-        $rot->{'y'} = abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
+        $rot->{'y'} = $F->{'Y_CLIP'} + abs((($YY - $F->{'Y_CLIP'}) - $rot->{'height'}) / 2);
 
         $F->blit_write($rot);
 
@@ -749,32 +749,38 @@ while (time < $s) {
 }
 
 {
+    print_it($F,'Testing Animated Images.  Loading...');
     opendir(my $DIR,'images/');
     chomp(my @list = readdir($DIR));
     closedir($DIR);
     @list = shuffle(@list);
     foreach my $info (@list) {
         next unless ($info =~ /\.gif$/i);
-        foreach my $bench (0 .. 1) {
-            for $angle (0 .. 1) {
+        for $angle (0 .. 1) {
+            if ($angle || $XX <= 320) {
+                print_it($F, "Loading Animated Image '$info' Scaled to Full Screen");
+                $image = $F->load_image(
+                    {
+                        'width'  => $XX,
+                        'height' => $YY - $F->{'Y_CLIP'},
+                        'file'   => "images/$info",
+                        'center' => 3
+                    }
+                );
+            } else {
+                print_it($F, "Loading Animated Image '$info' Native Size");
+                $image = $F->load_image(
+                    {
+                        'file'   => "images/$info",
+                        'center' => 3
+                    }
+                );
+            }
+            foreach my $bench (0 .. 1) {
                 if ($angle || $XX <= 320) {
                     print_it($F, $bench ? "Testing Animated Image Display of '$info' Fullscreen Benchmark" : "Testing Animated Image Display of '$info' Fullscreen");
-                    $image = $F->load_image(
-                        {
-                            'width'  => $XX,
-                            'height' => $YY - $F->{'Y_CLIP'},
-                            'file'   => "images/$info",
-                            'center' => 3
-                        }
-                    );
                 } else {
                     print_it($F, $bench ? "Testing Animated Image Display of '$info' Native Size Benchmark" : "Testing Animated Image Display of '$info' Native Size");
-                    $image = $F->load_image(
-                        {
-                            'file'   => "images/$info",
-                            'center' => 3
-                        }
-                    );
                 }
                 if (defined($image)) {
                     $F->cls();
@@ -804,8 +810,8 @@ while (time < $s) {
                         }
                     }
                 }
-                last if ($XX <= 320);
             }
+            last if ($XX <= 320);
         }
     }
 }
@@ -862,7 +868,7 @@ while (time < $s) {
 }
 
 {
-    print_it($F, 'Testing MASK Drawing Mode');
+    print_it($F, 'Testing MASK Drawing Mode (This is SLOOOOW)');
     my $h = int($YY - $F->{'Y_CLIP'});
     my $image1 = $F->load_image(
         {
@@ -881,19 +887,32 @@ while (time < $s) {
             'width'  => $XX,
             'height' => $h,
             'file'   => 'images/RWBY_beuowolf.jpg',
-            'center' => 3
+            'center' => 3,
+            'convertalpha' => 1
         }
     );
     $F->blit_write($image1);
-#    my $p = $F->pixel({'x'=>5,'y'=>$F->{'Y_CLIP'} + 5});print STDERR Dumper($p);sleep 50;
-
     $F->mask_mode();
     $F->blit_write($image2);
     sleep $factor;
+
+    print_it($F,'Simulating MASK Mode with the much quicker "blit_transform" and "merge"');
+    $F->blit_write($image1);
+    $F->blit_write(
+        $F->blit_transform(
+            {
+                'blit_data' => $image2,
+                'merge'     => {
+                    'dest_blit_data'=> $F->blit_read($image2)
+                }
+            }
+        )
+    );
+    sleep $factor;
 }
 
 {
-    print_it($F, 'Testing UNMASK Drawing Mode');
+    print_it($F, 'Testing UNMASK Drawing Mode (This is SLOOOW)');
     my $h = int($YY - $F->{'Y_CLIP'});
     my $image1 = $F->load_image(
         {
@@ -902,7 +921,8 @@ while (time < $s) {
             'width'  => $XX,
             'height' => $h,
             'file'   => 'images/RWBY_beuowolf.jpg',
-            'center' => 1
+            'center' => 1,
+            'convertalpha' => 1
         }
     );
     my $image2 = $F->load_image(
@@ -919,6 +939,20 @@ while (time < $s) {
     $F->unmask_mode();
     $F->blit_write($image2);
     sleep $factor;
+
+    print_it($F,'Simulating UNMASK Mode with the much quicker "blit_transform" and "merge"');
+    $F->blit_write($image2);
+    $F->blit_write(
+        $F->blit_transform(
+            {
+                'blit_data' => $image1,
+                'merge'     => {
+                    'dest_blit_data'=> $F->blit_read($image1)
+                }
+            }
+        )
+    );
+    sleep $factor;
 }
 
 $F->clip_reset();
@@ -941,7 +975,7 @@ sub print_it {
     $fb->normal_mode();
     $fb->clip_reset();
     $fb->cls();
-    unless ($XX < 320) {
+    unless ($XX <= 320) {
         $fb->or_mode();
 
         my $b = $fb->ttf_print(
